Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(571)

Unified Diff: services/ui/gpu/gpu_main.h

Issue 2797453002: Rename DisplayCompositor to MojoFrameSinkManager. (Closed)
Patch Set: Rebase. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/common/BUILD.gn ('k') | services/ui/gpu/gpu_main.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/gpu/gpu_main.h
diff --git a/services/ui/gpu/gpu_main.h b/services/ui/gpu/gpu_main.h
index 82accf9b3ab6f4d8147252df95de5cb3f32a6c57..1e839880c3ce4623838203582bbfeb933b5b204f 100644
--- a/services/ui/gpu/gpu_main.h
+++ b/services/ui/gpu/gpu_main.h
@@ -11,8 +11,8 @@
#include "gpu/ipc/service/gpu_init.h"
#include "services/ui/gpu/interfaces/gpu_main.mojom.h"
#include "services/ui/gpu/interfaces/gpu_service.mojom.h"
-#include "services/ui/surfaces/display_compositor.h"
#include "services/ui/surfaces/display_provider.h"
+#include "services/ui/surfaces/mojo_frame_sink_manager.h"
namespace gpu {
class GpuMemoryBufferFactory;
@@ -33,9 +33,9 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
mojom::GpuHostPtr gpu_host,
const gpu::GpuPreferences& preferences,
mojo::ScopedSharedBufferHandle activity_flags) override;
- void CreateDisplayCompositor(
- cc::mojom::DisplayCompositorRequest request,
- cc::mojom::DisplayCompositorClientPtr client) override;
+ void CreateFrameSinkManager(
+ cc::mojom::FrameSinkManagerRequest request,
+ cc::mojom::FrameSinkManagerClientPtr client) override;
void OnStart();
@@ -46,14 +46,14 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
scoped_refptr<base::SingleThreadTaskRunner> io_runner,
scoped_refptr<base::SingleThreadTaskRunner> compositor_runner);
- void CreateDisplayCompositorInternal(
- cc::mojom::DisplayCompositorRequest request,
- cc::mojom::DisplayCompositorClientPtrInfo client_info);
- void CreateDisplayCompositorOnCompositorThread(
+ void CreateFrameSinkManagerInternal(
+ cc::mojom::FrameSinkManagerRequest request,
+ cc::mojom::FrameSinkManagerClientPtrInfo client_info);
+ void CreateFrameSinkManagerOnCompositorThread(
gpu::ImageFactory* image_factory,
mojom::GpuServicePtrInfo gpu_service_info,
- cc::mojom::DisplayCompositorRequest request,
- cc::mojom::DisplayCompositorClientPtrInfo client_info);
+ cc::mojom::FrameSinkManagerRequest request,
+ cc::mojom::FrameSinkManagerClientPtrInfo client_info);
void CreateGpuServiceOnGpuThread(mojom::GpuServiceRequest request,
mojom::GpuHostPtrInfo gpu_host_info,
const gpu::GpuPreferences& preferences,
@@ -71,20 +71,21 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
std::unique_ptr<gpu::GpuInit> gpu_init_;
std::unique_ptr<GpuService> gpu_service_;
// The message-pipe used by the DisplayCompositor to request gpu memory
// buffers.
mojom::GpuServicePtr gpu_internal_;
// The InCommandCommandBuffer::Service used by the display compositor.
scoped_refptr<gpu::InProcessCommandBuffer::Service> gpu_command_service_;
// If the gpu service is not yet ready then we stash pending MessagePipes in
// these member variables.
- cc::mojom::DisplayCompositorRequest pending_display_compositor_request_;
- cc::mojom::DisplayCompositorClientPtrInfo
- pending_display_compositor_client_info_;
+ cc::mojom::FrameSinkManagerRequest pending_frame_sink_manager_request_;
+ cc::mojom::FrameSinkManagerClientPtrInfo
+ pending_frame_sink_manager_client_info_;
- std::unique_ptr<DisplayCompositor> display_compositor_;
+ // Provides mojo interfaces for creating and managing FrameSinks.
+ std::unique_ptr<MojoFrameSinkManager> frame_sink_manager_;
std::unique_ptr<DisplayProvider> display_provider_;
std::unique_ptr<gpu::GpuMemoryBufferFactory> gpu_memory_buffer_factory_;
@@ -96,9 +97,9 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
// The thread that handles IO events for Gpu.
base::Thread io_thread_;
// The display compositor gets its own thread in mus-gpu. The gpu service,
// where GL commands are processed resides on its own thread. Various
// components of the display compositor such as Display, ResourceProvider,
// and GLRenderer block on sync tokens from other command buffers. Thus,
// the gpu service must live on a separate thread.
base::Thread compositor_thread_;
@@ -71,20 +71,21 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
std::unique_ptr<gpu::GpuInit> gpu_init_;
std::unique_ptr<GpuService> gpu_service_;
- // The message-pipe used by the DisplayCompositor to request gpu memory
+ // The message-pipe used by the FrameSinkManager to request gpu memory
// buffers.
mojom::GpuServicePtr gpu_internal_;
@@ -71,20 +71,21 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
// buffers.
mojom::GpuServicePtr gpu_internal_;
- // The InCommandCommandBuffer::Service used by the display compositor.
+ // The InCommandCommandBuffer::Service used by the frame sink manager.
scoped_refptr<gpu::InProcessCommandBuffer::Service> gpu_command_service_;
// If the gpu service is not yet ready then we stash pending MessagePipes in
@@ -96,9 +97,9 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
// The thread that handles IO events for Gpu.
base::Thread io_thread_;
- // The display compositor gets its own thread in mus-gpu. The gpu service,
+ // The frame sink manager gets its own thread in mus-gpu. The gpu service,
// where GL commands are processed resides on its own thread. Various
@@ -96,9 +97,9 @@ class GpuMain : public gpu::GpuSandboxHelper, public mojom::GpuMain {
// where GL commands are processed resides on its own thread. Various
- // components of the display compositor such as Display, ResourceProvider,
+ // components of the frame sink manager such as Display, ResourceProvider,
// and GLRenderer block on sync tokens from other command buffers. Thus,
// the gpu service must live on a separate thread.
« no previous file with comments | « services/ui/common/BUILD.gn ('k') | services/ui/gpu/gpu_main.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698